"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AppCampaignBiddingStrategyGoalTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AppCampaignBiddingStrategyGoalType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AppCampaignBiddingStrategyGoalType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V(
                0
            )
        )
        UNKNOWN = (
            AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V(
                1
            )
        )
        OPTIMIZE_INSTALLS_TARGET_INSTALL_COST = (
            AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V(
                2
            )
        )
        OPTIMIZE_IN_APP_CONVERSIONS_TARGET_INSTALL_COST = (
            AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V(
                3
            )
        )
        OPTIMIZE_IN_APP_CONVERSIONS_TARGET_CONVERSION_COST = (
            AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V(
                4
            )
        )
        OPTIMIZE_RETURN_ON_ADVERTISING_SPEND = (
            AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V(
                5
            )
        )
    class AppCampaignBiddingStrategyGoalType(
        metaclass=_AppCampaignBiddingStrategyGoalType
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = (
        AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V(0)
    )
    UNKNOWN = (
        AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V(1)
    )
    OPTIMIZE_INSTALLS_TARGET_INSTALL_COST = (
        AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V(2)
    )
    OPTIMIZE_IN_APP_CONVERSIONS_TARGET_INSTALL_COST = (
        AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V(3)
    )
    OPTIMIZE_IN_APP_CONVERSIONS_TARGET_CONVERSION_COST = (
        AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V(4)
    )
    OPTIMIZE_RETURN_ON_ADVERTISING_SPEND = (
        AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType.V(5)
    )
    def __init__(
        self,
    ) -> None: ...

global___AppCampaignBiddingStrategyGoalTypeEnum = AppCampaignBiddingStrategyGoalTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.criteria_pb2
import google.ads.google_ads.v4.proto.enums.feed_item_target_device_pb2
import google.ads.google_ads.v4.proto.enums.feed_item_target_status_pb2
import google.ads.google_ads.v4.proto.enums.feed_item_target_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    FEED_ITEM_FIELD_NUMBER: builtins.int
    FEED_ITEM_TARGET_TYPE_FIELD_NUMBER: builtins.int
    FEED_ITEM_TARGET_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    AD_GROUP_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    GEO_TARGET_CONSTANT_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AD_SCHEDULE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    feed_item_target_type: google.ads.google_ads.v4.proto.enums.feed_item_target_type_pb2.FeedItemTargetTypeEnum.FeedItemTargetType.V = (
        ...
    )
    status: google.ads.google_ads.v4.proto.enums.feed_item_target_status_pb2.FeedItemTargetStatusEnum.FeedItemTargetStatus.V = (
        ...
    )
    device: google.ads.google_ads.v4.proto.enums.feed_item_target_device_pb2.FeedItemTargetDeviceEnum.FeedItemTargetDevice.V = (
        ...
    )
    @property
    def feed_item(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def feed_item_target_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def ad_group(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def keyword(
        self,
    ) -> google.ads.google_ads.v4.proto.common.criteria_pb2.KeywordInfo: ...
    @property
    def geo_target_constant(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def ad_schedule(
        self,
    ) -> google.ads.google_ads.v4.proto.common.criteria_pb2.AdScheduleInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        feed_item: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        feed_item_target_type: google.ads.google_ads.v4.proto.enums.feed_item_target_type_pb2.FeedItemTargetTypeEnum.FeedItemTargetType.V = ...,
        feed_item_target_id: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        status: google.ads.google_ads.v4.proto.enums.feed_item_target_status_pb2.FeedItemTargetStatusEnum.FeedItemTargetStatus.V = ...,
        campaign: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        ad_group: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        keyword: typing.Optional[
            google.ads.google_ads.v4.proto.common.criteria_pb2.KeywordInfo
        ] = ...,
        geo_target_constant: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        device: google.ads.google_ads.v4.proto.enums.feed_item_target_device_pb2.FeedItemTargetDeviceEnum.FeedItemTargetDevice.V = ...,
        ad_schedule: typing.Optional[
            google.ads.google_ads.v4.proto.common.criteria_pb2.AdScheduleInfo
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "ad_group",
            b"ad_group",
            "ad_schedule",
            b"ad_schedule",
            "campaign",
            b"campaign",
            "device",
            b"device",
            "feed_item",
            b"feed_item",
            "feed_item_target_id",
            b"feed_item_target_id",
            "geo_target_constant",
            b"geo_target_constant",
            "keyword",
            b"keyword",
            "target",
            b"target",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_group",
            b"ad_group",
            "ad_schedule",
            b"ad_schedule",
            "campaign",
            b"campaign",
            "device",
            b"device",
            "feed_item",
            b"feed_item",
            "feed_item_target_id",
            b"feed_item_target_id",
            "feed_item_target_type",
            b"feed_item_target_type",
            "geo_target_constant",
            b"geo_target_constant",
            "keyword",
            b"keyword",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "target",
            b"target",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["target", b"target"]
    ) -> typing_extensions.Literal[
        "campaign",
        "ad_group",
        "keyword",
        "geo_target_constant",
        "device",
        "ad_schedule",
    ]: ...

global___FeedItemTarget = FeedItemTarget



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LabelErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _LabelError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[LabelError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = LabelErrorEnum.LabelError.V(0)
        UNKNOWN = LabelErrorEnum.LabelError.V(1)
        CANNOT_APPLY_INACTIVE_LABEL = LabelErrorEnum.LabelError.V(2)
        CANNOT_APPLY_LABEL_TO_DISABLED_AD_GROUP_CRITERION = LabelErrorEnum.LabelError.V(
            3
        )
        CANNOT_APPLY_LABEL_TO_NEGATIVE_AD_GROUP_CRITERION = LabelErrorEnum.LabelError.V(
            4
        )
        EXCEEDED_LABEL_LIMIT_PER_TYPE = LabelErrorEnum.LabelError.V(5)
        INVALID_RESOURCE_FOR_MANAGER_LABEL = LabelErrorEnum.LabelError.V(6)
        DUPLICATE_NAME = LabelErrorEnum.LabelError.V(7)
        INVALID_LABEL_NAME = LabelErrorEnum.LabelError.V(8)
        CANNOT_ATTACH_LABEL_TO_DRAFT = LabelErrorEnum.LabelError.V(9)
        CANNOT_ATTACH_NON_MANAGER_LABEL_TO_CUSTOMER = LabelErrorEnum.LabelError.V(10)
    class LabelError(metaclass=_LabelError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = LabelErrorEnum.LabelError.V(0)
    UNKNOWN = LabelErrorEnum.LabelError.V(1)
    CANNOT_APPLY_INACTIVE_LABEL = LabelErrorEnum.LabelError.V(2)
    CANNOT_APPLY_LABEL_TO_DISABLED_AD_GROUP_CRITERION = LabelErrorEnum.LabelError.V(3)
    CANNOT_APPLY_LABEL_TO_NEGATIVE_AD_GROUP_CRITERION = LabelErrorEnum.LabelError.V(4)
    EXCEEDED_LABEL_LIMIT_PER_TYPE = LabelErrorEnum.LabelError.V(5)
    INVALID_RESOURCE_FOR_MANAGER_LABEL = LabelErrorEnum.LabelError.V(6)
    DUPLICATE_NAME = LabelErrorEnum.LabelError.V(7)
    INVALID_LABEL_NAME = LabelErrorEnum.LabelError.V(8)
    CANNOT_ATTACH_LABEL_TO_DRAFT = LabelErrorEnum.LabelError.V(9)
    CANNOT_ATTACH_NON_MANAGER_LABEL_TO_CUSTOMER = LabelErrorEnum.LabelError.V(10)
    def __init__(
        self,
    ) -> None: ...

global___LabelErrorEnum = LabelErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.keyword_plan_competition_level_pb2
import google.ads.google_ads.v5.proto.enums.month_of_year_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordPlanHistoricalMetrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AVG_MONTHLY_SEARCHES_FIELD_NUMBER: builtins.int
    MONTHLY_SEARCH_VOLUMES_FIELD_NUMBER: builtins.int
    COMPETITION_FIELD_NUMBER: builtins.int
    COMPETITION_INDEX_FIELD_NUMBER: builtins.int
    LOW_TOP_OF_PAGE_BID_MICROS_FIELD_NUMBER: builtins.int
    HIGH_TOP_OF_PAGE_BID_MICROS_FIELD_NUMBER: builtins.int
    competition: google.ads.google_ads.v5.proto.enums.keyword_plan_competition_level_pb2.KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevel.V = (
        ...
    )
    @property
    def avg_monthly_searches(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def monthly_search_volumes(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MonthlySearchVolume
    ]: ...
    @property
    def competition_index(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def low_top_of_page_bid_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def high_top_of_page_bid_micros(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        avg_monthly_searches: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        monthly_search_volumes: typing.Optional[
            typing.Iterable[global___MonthlySearchVolume]
        ] = ...,
        competition: google.ads.google_ads.v5.proto.enums.keyword_plan_competition_level_pb2.KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevel.V = ...,
        competition_index: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        low_top_of_page_bid_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        high_top_of_page_bid_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "avg_monthly_searches",
            b"avg_monthly_searches",
            "competition_index",
            b"competition_index",
            "high_top_of_page_bid_micros",
            b"high_top_of_page_bid_micros",
            "low_top_of_page_bid_micros",
            b"low_top_of_page_bid_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "avg_monthly_searches",
            b"avg_monthly_searches",
            "competition",
            b"competition",
            "competition_index",
            b"competition_index",
            "high_top_of_page_bid_micros",
            b"high_top_of_page_bid_micros",
            "low_top_of_page_bid_micros",
            b"low_top_of_page_bid_micros",
            "monthly_search_volumes",
            b"monthly_search_volumes",
        ],
    ) -> None: ...

global___KeywordPlanHistoricalMetrics = KeywordPlanHistoricalMetrics

class MonthlySearchVolume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    YEAR_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    MONTHLY_SEARCHES_FIELD_NUMBER: builtins.int
    month: google.ads.google_ads.v5.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = (
        ...
    )
    @property
    def year(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def monthly_searches(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        year: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        month: google.ads.google_ads.v5.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = ...,
        monthly_searches: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "monthly_searches", b"monthly_searches", "year", b"year"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "month", b"month", "monthly_searches", b"monthly_searches", "year", b"year"
        ],
    ) -> None: ...

global___MonthlySearchVolume = MonthlySearchVolume



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerFeedErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomerFeedError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomerFeedError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomerFeedErrorEnum.CustomerFeedError.V(0)
        UNKNOWN = CustomerFeedErrorEnum.CustomerFeedError.V(1)
        FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
            CustomerFeedErrorEnum.CustomerFeedError.V(2)
        )
        CANNOT_CREATE_FOR_REMOVED_FEED = CustomerFeedErrorEnum.CustomerFeedError.V(3)
        CANNOT_CREATE_ALREADY_EXISTING_CUSTOMER_FEED = (
            CustomerFeedErrorEnum.CustomerFeedError.V(4)
        )
        CANNOT_MODIFY_REMOVED_CUSTOMER_FEED = CustomerFeedErrorEnum.CustomerFeedError.V(
            5
        )
        INVALID_PLACEHOLDER_TYPE = CustomerFeedErrorEnum.CustomerFeedError.V(6)
        MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = (
            CustomerFeedErrorEnum.CustomerFeedError.V(7)
        )
        PLACEHOLDER_TYPE_NOT_ALLOWED_ON_CUSTOMER_FEED = (
            CustomerFeedErrorEnum.CustomerFeedError.V(8)
        )
    class CustomerFeedError(metaclass=_CustomerFeedError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomerFeedErrorEnum.CustomerFeedError.V(0)
    UNKNOWN = CustomerFeedErrorEnum.CustomerFeedError.V(1)
    FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
        CustomerFeedErrorEnum.CustomerFeedError.V(2)
    )
    CANNOT_CREATE_FOR_REMOVED_FEED = CustomerFeedErrorEnum.CustomerFeedError.V(3)
    CANNOT_CREATE_ALREADY_EXISTING_CUSTOMER_FEED = (
        CustomerFeedErrorEnum.CustomerFeedError.V(4)
    )
    CANNOT_MODIFY_REMOVED_CUSTOMER_FEED = CustomerFeedErrorEnum.CustomerFeedError.V(5)
    INVALID_PLACEHOLDER_TYPE = CustomerFeedErrorEnum.CustomerFeedError.V(6)
    MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = (
        CustomerFeedErrorEnum.CustomerFeedError.V(7)
    )
    PLACEHOLDER_TYPE_NOT_ALLOWED_ON_CUSTOMER_FEED = (
        CustomerFeedErrorEnum.CustomerFeedError.V(8)
    )
    def __init__(
        self,
    ) -> None: ...

global___CustomerFeedErrorEnum = CustomerFeedErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.feed_pb2
import grpc

from .feed_service_pb2 import *

class FeedServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetFeed(
        self,
        request: global___GetFeedRequest,
    ) -> google.ads.google_ads.v6.proto.resources.feed_pb2.Feed: ...
    def MutateFeeds(
        self,
        request: global___MutateFeedsRequest,
    ) -> global___MutateFeedsResponse: ...

class FeedServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetFeed(
        self,
        request: global___GetFeedRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.feed_pb2.Feed: ...
    @abc.abstractmethod
    def MutateFeeds(
        self,
        request: global___MutateFeedsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateFeedsResponse: ...

def add_FeedServiceServicer_to_server(
    servicer: FeedServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ProductCustomAttributeIndexEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ProductCustomAttributeIndex(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ProductCustomAttributeIndex.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(0)
        UNKNOWN = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(1)
        INDEX0 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(7)
        INDEX1 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(8)
        INDEX2 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(9)
        INDEX3 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(10)
        INDEX4 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(11)
    class ProductCustomAttributeIndex(metaclass=_ProductCustomAttributeIndex):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(0)
    UNKNOWN = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(1)
    INDEX0 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(7)
    INDEX1 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(8)
    INDEX2 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(9)
    INDEX3 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(10)
    INDEX4 = ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V(11)
    def __init__(
        self,
    ) -> None: ...

global___ProductCustomAttributeIndexEnum = ProductCustomAttributeIndexEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class StructuredSnippetPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _StructuredSnippetPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            StructuredSnippetPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderField.V(0)
        )
        UNKNOWN = (
            StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderField.V(1)
        )
        HEADER = (
            StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderField.V(2)
        )
        SNIPPETS = (
            StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderField.V(3)
        )
    class StructuredSnippetPlaceholderField(
        metaclass=_StructuredSnippetPlaceholderField
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = (
        StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderField.V(0)
    )
    UNKNOWN = StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderField.V(
        1
    )
    HEADER = StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderField.V(
        2
    )
    SNIPPETS = (
        StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderField.V(3)
    )
    def __init__(
        self,
    ) -> None: ...

global___StructuredSnippetPlaceholderFieldEnum = StructuredSnippetPlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.shopping_performance_view_pb2
import grpc

from .shopping_performance_view_service_pb2 import *

class ShoppingPerformanceViewServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetShoppingPerformanceView(
        self,
        request: global___GetShoppingPerformanceViewRequest,
    ) -> google.ads.google_ads.v6.proto.resources.shopping_performance_view_pb2.ShoppingPerformanceView: ...

class ShoppingPerformanceViewServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetShoppingPerformanceView(
        self,
        request: global___GetShoppingPerformanceViewRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.shopping_performance_view_pb2.ShoppingPerformanceView: ...

def add_ShoppingPerformanceViewServiceServicer_to_server(
    servicer: ShoppingPerformanceViewServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.custom_interest_pb2
import grpc

from .custom_interest_service_pb2 import *

class CustomInterestServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomInterest(
        self,
        request: global___GetCustomInterestRequest,
    ) -> google.ads.google_ads.v4.proto.resources.custom_interest_pb2.CustomInterest: ...
    def MutateCustomInterests(
        self,
        request: global___MutateCustomInterestsRequest,
    ) -> global___MutateCustomInterestsResponse: ...

class CustomInterestServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomInterest(
        self,
        request: global___GetCustomInterestRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.custom_interest_pb2.CustomInterest: ...
    @abc.abstractmethod
    def MutateCustomInterests(
        self,
        request: global___MutateCustomInterestsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomInterestsResponse: ...

def add_CustomInterestServiceServicer_to_server(
    servicer: CustomInterestServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.resources.payments_account_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ListPaymentsAccountsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["customer_id", b"customer_id"]
    ) -> None: ...

global___ListPaymentsAccountsRequest = ListPaymentsAccountsRequest

class ListPaymentsAccountsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PAYMENTS_ACCOUNTS_FIELD_NUMBER: builtins.int
    @property
    def payments_accounts(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.resources.payments_account_pb2.PaymentsAccount
    ]: ...
    def __init__(
        self,
        *,
        payments_accounts: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.resources.payments_account_pb2.PaymentsAccount
            ]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "payments_accounts", b"payments_accounts"
        ],
    ) -> None: ...

global___ListPaymentsAccountsResponse = ListPaymentsAccountsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AuthorizationErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AuthorizationError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AuthorizationError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AuthorizationErrorEnum.AuthorizationError.V(0)
        UNKNOWN = AuthorizationErrorEnum.AuthorizationError.V(1)
        USER_PERMISSION_DENIED = AuthorizationErrorEnum.AuthorizationError.V(2)
        DEVELOPER_TOKEN_NOT_ON_ALLOWLIST = AuthorizationErrorEnum.AuthorizationError.V(
            13
        )
        DEVELOPER_TOKEN_PROHIBITED = AuthorizationErrorEnum.AuthorizationError.V(4)
        PROJECT_DISABLED = AuthorizationErrorEnum.AuthorizationError.V(5)
        AUTHORIZATION_ERROR = AuthorizationErrorEnum.AuthorizationError.V(6)
        ACTION_NOT_PERMITTED = AuthorizationErrorEnum.AuthorizationError.V(7)
        INCOMPLETE_SIGNUP = AuthorizationErrorEnum.AuthorizationError.V(8)
        CUSTOMER_NOT_ENABLED = AuthorizationErrorEnum.AuthorizationError.V(24)
        MISSING_TOS = AuthorizationErrorEnum.AuthorizationError.V(9)
        DEVELOPER_TOKEN_NOT_APPROVED = AuthorizationErrorEnum.AuthorizationError.V(10)
        INVALID_LOGIN_CUSTOMER_ID_SERVING_CUSTOMER_ID_COMBINATION = (
            AuthorizationErrorEnum.AuthorizationError.V(11)
        )
        SERVICE_ACCESS_DENIED = AuthorizationErrorEnum.AuthorizationError.V(12)
        ACCESS_DENIED_FOR_ACCOUNT_TYPE = AuthorizationErrorEnum.AuthorizationError.V(25)
    class AuthorizationError(metaclass=_AuthorizationError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AuthorizationErrorEnum.AuthorizationError.V(0)
    UNKNOWN = AuthorizationErrorEnum.AuthorizationError.V(1)
    USER_PERMISSION_DENIED = AuthorizationErrorEnum.AuthorizationError.V(2)
    DEVELOPER_TOKEN_NOT_ON_ALLOWLIST = AuthorizationErrorEnum.AuthorizationError.V(13)
    DEVELOPER_TOKEN_PROHIBITED = AuthorizationErrorEnum.AuthorizationError.V(4)
    PROJECT_DISABLED = AuthorizationErrorEnum.AuthorizationError.V(5)
    AUTHORIZATION_ERROR = AuthorizationErrorEnum.AuthorizationError.V(6)
    ACTION_NOT_PERMITTED = AuthorizationErrorEnum.AuthorizationError.V(7)
    INCOMPLETE_SIGNUP = AuthorizationErrorEnum.AuthorizationError.V(8)
    CUSTOMER_NOT_ENABLED = AuthorizationErrorEnum.AuthorizationError.V(24)
    MISSING_TOS = AuthorizationErrorEnum.AuthorizationError.V(9)
    DEVELOPER_TOKEN_NOT_APPROVED = AuthorizationErrorEnum.AuthorizationError.V(10)
    INVALID_LOGIN_CUSTOMER_ID_SERVING_CUSTOMER_ID_COMBINATION = (
        AuthorizationErrorEnum.AuthorizationError.V(11)
    )
    SERVICE_ACCESS_DENIED = AuthorizationErrorEnum.AuthorizationError.V(12)
    ACCESS_DENIED_FOR_ACCOUNT_TYPE = AuthorizationErrorEnum.AuthorizationError.V(25)
    def __init__(
        self,
    ) -> None: ...

global___AuthorizationErrorEnum = AuthorizationErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PriceExtensionTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PriceExtensionType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PriceExtensionType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PriceExtensionTypeEnum.PriceExtensionType.V(0)
        UNKNOWN = PriceExtensionTypeEnum.PriceExtensionType.V(1)
        BRANDS = PriceExtensionTypeEnum.PriceExtensionType.V(2)
        EVENTS = PriceExtensionTypeEnum.PriceExtensionType.V(3)
        LOCATIONS = PriceExtensionTypeEnum.PriceExtensionType.V(4)
        NEIGHBORHOODS = PriceExtensionTypeEnum.PriceExtensionType.V(5)
        PRODUCT_CATEGORIES = PriceExtensionTypeEnum.PriceExtensionType.V(6)
        PRODUCT_TIERS = PriceExtensionTypeEnum.PriceExtensionType.V(7)
        SERVICES = PriceExtensionTypeEnum.PriceExtensionType.V(8)
        SERVICE_CATEGORIES = PriceExtensionTypeEnum.PriceExtensionType.V(9)
        SERVICE_TIERS = PriceExtensionTypeEnum.PriceExtensionType.V(10)
    class PriceExtensionType(metaclass=_PriceExtensionType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PriceExtensionTypeEnum.PriceExtensionType.V(0)
    UNKNOWN = PriceExtensionTypeEnum.PriceExtensionType.V(1)
    BRANDS = PriceExtensionTypeEnum.PriceExtensionType.V(2)
    EVENTS = PriceExtensionTypeEnum.PriceExtensionType.V(3)
    LOCATIONS = PriceExtensionTypeEnum.PriceExtensionType.V(4)
    NEIGHBORHOODS = PriceExtensionTypeEnum.PriceExtensionType.V(5)
    PRODUCT_CATEGORIES = PriceExtensionTypeEnum.PriceExtensionType.V(6)
    PRODUCT_TIERS = PriceExtensionTypeEnum.PriceExtensionType.V(7)
    SERVICES = PriceExtensionTypeEnum.PriceExtensionType.V(8)
    SERVICE_CATEGORIES = PriceExtensionTypeEnum.PriceExtensionType.V(9)
    SERVICE_TIERS = PriceExtensionTypeEnum.PriceExtensionType.V(10)
    def __init__(
        self,
    ) -> None: ...

global___PriceExtensionTypeEnum = PriceExtensionTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupAdErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupAdError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdGroupAdError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdGroupAdErrorEnum.AdGroupAdError.V(0)
        UNKNOWN = AdGroupAdErrorEnum.AdGroupAdError.V(1)
        AD_GROUP_AD_LABEL_DOES_NOT_EXIST = AdGroupAdErrorEnum.AdGroupAdError.V(2)
        AD_GROUP_AD_LABEL_ALREADY_EXISTS = AdGroupAdErrorEnum.AdGroupAdError.V(3)
        AD_NOT_UNDER_ADGROUP = AdGroupAdErrorEnum.AdGroupAdError.V(4)
        CANNOT_OPERATE_ON_REMOVED_ADGROUPAD = AdGroupAdErrorEnum.AdGroupAdError.V(5)
        CANNOT_CREATE_DEPRECATED_ADS = AdGroupAdErrorEnum.AdGroupAdError.V(6)
        CANNOT_CREATE_TEXT_ADS = AdGroupAdErrorEnum.AdGroupAdError.V(7)
        EMPTY_FIELD = AdGroupAdErrorEnum.AdGroupAdError.V(8)
        RESOURCE_REFERENCED_IN_MULTIPLE_OPS = AdGroupAdErrorEnum.AdGroupAdError.V(9)
        AD_TYPE_CANNOT_BE_PAUSED = AdGroupAdErrorEnum.AdGroupAdError.V(10)
        AD_TYPE_CANNOT_BE_REMOVED = AdGroupAdErrorEnum.AdGroupAdError.V(11)
    class AdGroupAdError(metaclass=_AdGroupAdError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupAdErrorEnum.AdGroupAdError.V(0)
    UNKNOWN = AdGroupAdErrorEnum.AdGroupAdError.V(1)
    AD_GROUP_AD_LABEL_DOES_NOT_EXIST = AdGroupAdErrorEnum.AdGroupAdError.V(2)
    AD_GROUP_AD_LABEL_ALREADY_EXISTS = AdGroupAdErrorEnum.AdGroupAdError.V(3)
    AD_NOT_UNDER_ADGROUP = AdGroupAdErrorEnum.AdGroupAdError.V(4)
    CANNOT_OPERATE_ON_REMOVED_ADGROUPAD = AdGroupAdErrorEnum.AdGroupAdError.V(5)
    CANNOT_CREATE_DEPRECATED_ADS = AdGroupAdErrorEnum.AdGroupAdError.V(6)
    CANNOT_CREATE_TEXT_ADS = AdGroupAdErrorEnum.AdGroupAdError.V(7)
    EMPTY_FIELD = AdGroupAdErrorEnum.AdGroupAdError.V(8)
    RESOURCE_REFERENCED_IN_MULTIPLE_OPS = AdGroupAdErrorEnum.AdGroupAdError.V(9)
    AD_TYPE_CANNOT_BE_PAUSED = AdGroupAdErrorEnum.AdGroupAdError.V(10)
    AD_TYPE_CANNOT_BE_REMOVED = AdGroupAdErrorEnum.AdGroupAdError.V(11)
    def __init__(
        self,
    ) -> None: ...

global___AdGroupAdErrorEnum = AdGroupAdErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UrlCollection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    URL_COLLECTION_ID_FIELD_NUMBER: builtins.int
    FINAL_URLS_FIELD_NUMBER: builtins.int
    FINAL_MOBILE_URLS_FIELD_NUMBER: builtins.int
    TRACKING_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    url_collection_id: typing.Text = ...
    final_urls: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    final_mobile_urls: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    tracking_url_template: typing.Text = ...
    def __init__(
        self,
        *,
        url_collection_id: typing.Text = ...,
        final_urls: typing.Optional[typing.Iterable[typing.Text]] = ...,
        final_mobile_urls: typing.Optional[typing.Iterable[typing.Text]] = ...,
        tracking_url_template: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_tracking_url_template",
            b"_tracking_url_template",
            "_url_collection_id",
            b"_url_collection_id",
            "tracking_url_template",
            b"tracking_url_template",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_tracking_url_template",
            b"_tracking_url_template",
            "_url_collection_id",
            b"_url_collection_id",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_urls",
            b"final_urls",
            "tracking_url_template",
            b"tracking_url_template",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_tracking_url_template", b"_tracking_url_template"
        ],
    ) -> typing_extensions.Literal["tracking_url_template"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_url_collection_id", b"_url_collection_id"
        ],
    ) -> typing_extensions.Literal["url_collection_id"]: ...

global___UrlCollection = UrlCollection



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.user_identifier_source_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OfflineUserAddressInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HASHED_FIRST_NAME_FIELD_NUMBER: builtins.int
    HASHED_LAST_NAME_FIELD_NUMBER: builtins.int
    CITY_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    POSTAL_CODE_FIELD_NUMBER: builtins.int
    hashed_first_name: typing.Text = ...
    hashed_last_name: typing.Text = ...
    city: typing.Text = ...
    state: typing.Text = ...
    country_code: typing.Text = ...
    postal_code: typing.Text = ...
    def __init__(
        self,
        *,
        hashed_first_name: typing.Text = ...,
        hashed_last_name: typing.Text = ...,
        city: typing.Text = ...,
        state: typing.Text = ...,
        country_code: typing.Text = ...,
        postal_code: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_city",
            b"_city",
            "_country_code",
            b"_country_code",
            "_hashed_first_name",
            b"_hashed_first_name",
            "_hashed_last_name",
            b"_hashed_last_name",
            "_postal_code",
            b"_postal_code",
            "_state",
            b"_state",
            "city",
            b"city",
            "country_code",
            b"country_code",
            "hashed_first_name",
            b"hashed_first_name",
            "hashed_last_name",
            b"hashed_last_name",
            "postal_code",
            b"postal_code",
            "state",
            b"state",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_city",
            b"_city",
            "_country_code",
            b"_country_code",
            "_hashed_first_name",
            b"_hashed_first_name",
            "_hashed_last_name",
            b"_hashed_last_name",
            "_postal_code",
            b"_postal_code",
            "_state",
            b"_state",
            "city",
            b"city",
            "country_code",
            b"country_code",
            "hashed_first_name",
            b"hashed_first_name",
            "hashed_last_name",
            b"hashed_last_name",
            "postal_code",
            b"postal_code",
            "state",
            b"state",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_city", b"_city"]
    ) -> typing_extensions.Literal["city"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_country_code", b"_country_code"]
    ) -> typing_extensions.Literal["country_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hashed_first_name", b"_hashed_first_name"
        ],
    ) -> typing_extensions.Literal["hashed_first_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hashed_last_name", b"_hashed_last_name"
        ],
    ) -> typing_extensions.Literal["hashed_last_name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_postal_code", b"_postal_code"]
    ) -> typing_extensions.Literal["postal_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_state", b"_state"]
    ) -> typing_extensions.Literal["state"]: ...

global___OfflineUserAddressInfo = OfflineUserAddressInfo

class UserIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    USER_IDENTIFIER_SOURCE_FIELD_NUMBER: builtins.int
    HASHED_EMAIL_FIELD_NUMBER: builtins.int
    HASHED_PHONE_NUMBER_FIELD_NUMBER: builtins.int
    MOBILE_ID_FIELD_NUMBER: builtins.int
    THIRD_PARTY_USER_ID_FIELD_NUMBER: builtins.int
    ADDRESS_INFO_FIELD_NUMBER: builtins.int
    user_identifier_source: google.ads.google_ads.v6.proto.enums.user_identifier_source_pb2.UserIdentifierSourceEnum.UserIdentifierSource.V = (
        ...
    )
    hashed_email: typing.Text = ...
    hashed_phone_number: typing.Text = ...
    mobile_id: typing.Text = ...
    third_party_user_id: typing.Text = ...
    @property
    def address_info(self) -> global___OfflineUserAddressInfo: ...
    def __init__(
        self,
        *,
        user_identifier_source: google.ads.google_ads.v6.proto.enums.user_identifier_source_pb2.UserIdentifierSourceEnum.UserIdentifierSource.V = ...,
        hashed_email: typing.Text = ...,
        hashed_phone_number: typing.Text = ...,
        mobile_id: typing.Text = ...,
        third_party_user_id: typing.Text = ...,
        address_info: typing.Optional[global___OfflineUserAddressInfo] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "address_info",
            b"address_info",
            "hashed_email",
            b"hashed_email",
            "hashed_phone_number",
            b"hashed_phone_number",
            "identifier",
            b"identifier",
            "mobile_id",
            b"mobile_id",
            "third_party_user_id",
            b"third_party_user_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "address_info",
            b"address_info",
            "hashed_email",
            b"hashed_email",
            "hashed_phone_number",
            b"hashed_phone_number",
            "identifier",
            b"identifier",
            "mobile_id",
            b"mobile_id",
            "third_party_user_id",
            b"third_party_user_id",
            "user_identifier_source",
            b"user_identifier_source",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["identifier", b"identifier"]
    ) -> typing_extensions.Literal[
        "hashed_email",
        "hashed_phone_number",
        "mobile_id",
        "third_party_user_id",
        "address_info",
    ]: ...

global___UserIdentifier = UserIdentifier

class TransactionAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TRANSACTION_DATE_TIME_FIELD_NUMBER: builtins.int
    TRANSACTION_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    ORDER_ID_FIELD_NUMBER: builtins.int
    STORE_ATTRIBUTE_FIELD_NUMBER: builtins.int
    CUSTOM_VALUE_FIELD_NUMBER: builtins.int
    transaction_date_time: typing.Text = ...
    transaction_amount_micros: builtins.float = ...
    currency_code: typing.Text = ...
    conversion_action: typing.Text = ...
    order_id: typing.Text = ...
    custom_value: typing.Text = ...
    @property
    def store_attribute(self) -> global___StoreAttribute: ...
    def __init__(
        self,
        *,
        transaction_date_time: typing.Text = ...,
        transaction_amount_micros: builtins.float = ...,
        currency_code: typing.Text = ...,
        conversion_action: typing.Text = ...,
        order_id: typing.Text = ...,
        store_attribute: typing.Optional[global___StoreAttribute] = ...,
        custom_value: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_action",
            b"_conversion_action",
            "_currency_code",
            b"_currency_code",
            "_custom_value",
            b"_custom_value",
            "_order_id",
            b"_order_id",
            "_transaction_amount_micros",
            b"_transaction_amount_micros",
            "_transaction_date_time",
            b"_transaction_date_time",
            "conversion_action",
            b"conversion_action",
            "currency_code",
            b"currency_code",
            "custom_value",
            b"custom_value",
            "order_id",
            b"order_id",
            "store_attribute",
            b"store_attribute",
            "transaction_amount_micros",
            b"transaction_amount_micros",
            "transaction_date_time",
            b"transaction_date_time",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_action",
            b"_conversion_action",
            "_currency_code",
            b"_currency_code",
            "_custom_value",
            b"_custom_value",
            "_order_id",
            b"_order_id",
            "_transaction_amount_micros",
            b"_transaction_amount_micros",
            "_transaction_date_time",
            b"_transaction_date_time",
            "conversion_action",
            b"conversion_action",
            "currency_code",
            b"currency_code",
            "custom_value",
            b"custom_value",
            "order_id",
            b"order_id",
            "store_attribute",
            b"store_attribute",
            "transaction_amount_micros",
            b"transaction_amount_micros",
            "transaction_date_time",
            b"transaction_date_time",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions.Literal["conversion_action"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions.Literal["currency_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_custom_value", b"_custom_value"]
    ) -> typing_extensions.Literal["custom_value"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_order_id", b"_order_id"]
    ) -> typing_extensions.Literal["order_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_transaction_amount_micros", b"_transaction_amount_micros"
        ],
    ) -> typing_extensions.Literal["transaction_amount_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_transaction_date_time", b"_transaction_date_time"
        ],
    ) -> typing_extensions.Literal["transaction_date_time"]: ...

global___TransactionAttribute = TransactionAttribute

class StoreAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STORE_CODE_FIELD_NUMBER: builtins.int
    store_code: typing.Text = ...
    def __init__(
        self,
        *,
        store_code: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_store_code", b"_store_code", "store_code", b"store_code"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_store_code", b"_store_code", "store_code", b"store_code"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_store_code", b"_store_code"]
    ) -> typing_extensions.Literal["store_code"]: ...

global___StoreAttribute = StoreAttribute

class UserData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    USER_IDENTIFIERS_FIELD_NUMBER: builtins.int
    TRANSACTION_ATTRIBUTE_FIELD_NUMBER: builtins.int
    USER_ATTRIBUTE_FIELD_NUMBER: builtins.int
    @property
    def user_identifiers(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___UserIdentifier
    ]: ...
    @property
    def transaction_attribute(self) -> global___TransactionAttribute: ...
    @property
    def user_attribute(self) -> global___UserAttribute: ...
    def __init__(
        self,
        *,
        user_identifiers: typing.Optional[
            typing.Iterable[global___UserIdentifier]
        ] = ...,
        transaction_attribute: typing.Optional[global___TransactionAttribute] = ...,
        user_attribute: typing.Optional[global___UserAttribute] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "transaction_attribute",
            b"transaction_attribute",
            "user_attribute",
            b"user_attribute",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "transaction_attribute",
            b"transaction_attribute",
            "user_attribute",
            b"user_attribute",
            "user_identifiers",
            b"user_identifiers",
        ],
    ) -> None: ...

global___UserData = UserData

class UserAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LIFETIME_VALUE_MICROS_FIELD_NUMBER: builtins.int
    LIFETIME_VALUE_BUCKET_FIELD_NUMBER: builtins.int
    lifetime_value_micros: builtins.int = ...
    lifetime_value_bucket: builtins.int = ...
    def __init__(
        self,
        *,
        lifetime_value_micros: builtins.int = ...,
        lifetime_value_bucket: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_lifetime_value_bucket",
            b"_lifetime_value_bucket",
            "_lifetime_value_micros",
            b"_lifetime_value_micros",
            "lifetime_value_bucket",
            b"lifetime_value_bucket",
            "lifetime_value_micros",
            b"lifetime_value_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_lifetime_value_bucket",
            b"_lifetime_value_bucket",
            "_lifetime_value_micros",
            b"_lifetime_value_micros",
            "lifetime_value_bucket",
            b"lifetime_value_bucket",
            "lifetime_value_micros",
            b"lifetime_value_micros",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_lifetime_value_bucket", b"_lifetime_value_bucket"
        ],
    ) -> typing_extensions.Literal["lifetime_value_bucket"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_lifetime_value_micros", b"_lifetime_value_micros"
        ],
    ) -> typing_extensions.Literal["lifetime_value_micros"]: ...

global___UserAttribute = UserAttribute

class CustomerMatchUserListMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    USER_LIST_FIELD_NUMBER: builtins.int
    user_list: typing.Text = ...
    def __init__(
        self,
        *,
        user_list: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_user_list", b"_user_list", "user_list", b"user_list"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_user_list", b"_user_list", "user_list", b"user_list"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_user_list", b"_user_list"]
    ) -> typing_extensions.Literal["user_list"]: ...

global___CustomerMatchUserListMetadata = CustomerMatchUserListMetadata

class StoreSalesMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LOYALTY_FRACTION_FIELD_NUMBER: builtins.int
    TRANSACTION_UPLOAD_FRACTION_FIELD_NUMBER: builtins.int
    CUSTOM_KEY_FIELD_NUMBER: builtins.int
    THIRD_PARTY_METADATA_FIELD_NUMBER: builtins.int
    loyalty_fraction: builtins.float = ...
    transaction_upload_fraction: builtins.float = ...
    custom_key: typing.Text = ...
    @property
    def third_party_metadata(self) -> global___StoreSalesThirdPartyMetadata: ...
    def __init__(
        self,
        *,
        loyalty_fraction: builtins.float = ...,
        transaction_upload_fraction: builtins.float = ...,
        custom_key: typing.Text = ...,
        third_party_metadata: typing.Optional[
            global___StoreSalesThirdPartyMetadata
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_custom_key",
            b"_custom_key",
            "_loyalty_fraction",
            b"_loyalty_fraction",
            "_transaction_upload_fraction",
            b"_transaction_upload_fraction",
            "custom_key",
            b"custom_key",
            "loyalty_fraction",
            b"loyalty_fraction",
            "third_party_metadata",
            b"third_party_metadata",
            "transaction_upload_fraction",
            b"transaction_upload_fraction",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_custom_key",
            b"_custom_key",
            "_loyalty_fraction",
            b"_loyalty_fraction",
            "_transaction_upload_fraction",
            b"_transaction_upload_fraction",
            "custom_key",
            b"custom_key",
            "loyalty_fraction",
            b"loyalty_fraction",
            "third_party_metadata",
            b"third_party_metadata",
            "transaction_upload_fraction",
            b"transaction_upload_fraction",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_custom_key", b"_custom_key"]
    ) -> typing_extensions.Literal["custom_key"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_loyalty_fraction", b"_loyalty_fraction"
        ],
    ) -> typing_extensions.Literal["loyalty_fraction"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_transaction_upload_fraction", b"_transaction_upload_fraction"
        ],
    ) -> typing_extensions.Literal["transaction_upload_fraction"]: ...

global___StoreSalesMetadata = StoreSalesMetadata

class StoreSalesThirdPartyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADVERTISER_UPLOAD_DATE_TIME_FIELD_NUMBER: builtins.int
    VALID_TRANSACTION_FRACTION_FIELD_NUMBER: builtins.int
    PARTNER_MATCH_FRACTION_FIELD_NUMBER: builtins.int
    PARTNER_UPLOAD_FRACTION_FIELD_NUMBER: builtins.int
    BRIDGE_MAP_VERSION_ID_FIELD_NUMBER: builtins.int
    PARTNER_ID_FIELD_NUMBER: builtins.int
    advertiser_upload_date_time: typing.Text = ...
    valid_transaction_fraction: builtins.float = ...
    partner_match_fraction: builtins.float = ...
    partner_upload_fraction: builtins.float = ...
    bridge_map_version_id: typing.Text = ...
    partner_id: builtins.int = ...
    def __init__(
        self,
        *,
        advertiser_upload_date_time: typing.Text = ...,
        valid_transaction_fraction: builtins.float = ...,
        partner_match_fraction: builtins.float = ...,
        partner_upload_fraction: builtins.float = ...,
        bridge_map_version_id: typing.Text = ...,
        partner_id: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_advertiser_upload_date_time",
            b"_advertiser_upload_date_time",
            "_bridge_map_version_id",
            b"_bridge_map_version_id",
            "_partner_id",
            b"_partner_id",
            "_partner_match_fraction",
            b"_partner_match_fraction",
            "_partner_upload_fraction",
            b"_partner_upload_fraction",
            "_valid_transaction_fraction",
            b"_valid_transaction_fraction",
            "advertiser_upload_date_time",
            b"advertiser_upload_date_time",
            "bridge_map_version_id",
            b"bridge_map_version_id",
            "partner_id",
            b"partner_id",
            "partner_match_fraction",
            b"partner_match_fraction",
            "partner_upload_fraction",
            b"partner_upload_fraction",
            "valid_transaction_fraction",
            b"valid_transaction_fraction",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_advertiser_upload_date_time",
            b"_advertiser_upload_date_time",
            "_bridge_map_version_id",
            b"_bridge_map_version_id",
            "_partner_id",
            b"_partner_id",
            "_partner_match_fraction",
            b"_partner_match_fraction",
            "_partner_upload_fraction",
            b"_partner_upload_fraction",
            "_valid_transaction_fraction",
            b"_valid_transaction_fraction",
            "advertiser_upload_date_time",
            b"advertiser_upload_date_time",
            "bridge_map_version_id",
            b"bridge_map_version_id",
            "partner_id",
            b"partner_id",
            "partner_match_fraction",
            b"partner_match_fraction",
            "partner_upload_fraction",
            b"partner_upload_fraction",
            "valid_transaction_fraction",
            b"valid_transaction_fraction",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_advertiser_upload_date_time", b"_advertiser_upload_date_time"
        ],
    ) -> typing_extensions.Literal["advertiser_upload_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_bridge_map_version_id", b"_bridge_map_version_id"
        ],
    ) -> typing_extensions.Literal["bridge_map_version_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_partner_id", b"_partner_id"]
    ) -> typing_extensions.Literal["partner_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_partner_match_fraction", b"_partner_match_fraction"
        ],
    ) -> typing_extensions.Literal["partner_match_fraction"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_partner_upload_fraction", b"_partner_upload_fraction"
        ],
    ) -> typing_extensions.Literal["partner_upload_fraction"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_valid_transaction_fraction", b"_valid_transaction_fraction"
        ],
    ) -> typing_extensions.Literal["valid_transaction_fraction"]: ...

global___StoreSalesThirdPartyMetadata = StoreSalesThirdPartyMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.criteria_pb2
import google.ads.google_ads.v5.proto.enums.criterion_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SharedCriterion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    SHARED_SET_FIELD_NUMBER: builtins.int
    CRITERION_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEO_FIELD_NUMBER: builtins.int
    YOUTUBE_CHANNEL_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    MOBILE_APP_CATEGORY_FIELD_NUMBER: builtins.int
    MOBILE_APPLICATION_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    shared_set: typing.Text = ...
    criterion_id: builtins.int = ...
    type: google.ads.google_ads.v5.proto.enums.criterion_type_pb2.CriterionTypeEnum.CriterionType.V = (
        ...
    )
    @property
    def keyword(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.KeywordInfo: ...
    @property
    def youtube_video(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.YouTubeVideoInfo: ...
    @property
    def youtube_channel(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.YouTubeChannelInfo: ...
    @property
    def placement(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.PlacementInfo: ...
    @property
    def mobile_app_category(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.MobileAppCategoryInfo: ...
    @property
    def mobile_application(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.MobileApplicationInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        shared_set: typing.Text = ...,
        criterion_id: builtins.int = ...,
        type: google.ads.google_ads.v5.proto.enums.criterion_type_pb2.CriterionTypeEnum.CriterionType.V = ...,
        keyword: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.KeywordInfo
        ] = ...,
        youtube_video: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.YouTubeVideoInfo
        ] = ...,
        youtube_channel: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.YouTubeChannelInfo
        ] = ...,
        placement: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.PlacementInfo
        ] = ...,
        mobile_app_category: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.MobileAppCategoryInfo
        ] = ...,
        mobile_application: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.MobileApplicationInfo
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_criterion_id",
            b"_criterion_id",
            "_shared_set",
            b"_shared_set",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "keyword",
            b"keyword",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "placement",
            b"placement",
            "shared_set",
            b"shared_set",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_criterion_id",
            b"_criterion_id",
            "_shared_set",
            b"_shared_set",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "keyword",
            b"keyword",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "placement",
            b"placement",
            "resource_name",
            b"resource_name",
            "shared_set",
            b"shared_set",
            "type",
            b"type",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_criterion_id", b"_criterion_id"]
    ) -> typing_extensions.Literal["criterion_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_shared_set", b"_shared_set"]
    ) -> typing_extensions.Literal["shared_set"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["criterion", b"criterion"]
    ) -> typing_extensions.Literal[
        "keyword",
        "youtube_video",
        "youtube_channel",
        "placement",
        "mobile_app_category",
        "mobile_application",
    ]: ...

global___SharedCriterion = SharedCriterion



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.placement_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DetailPlacementView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    GROUP_PLACEMENT_TARGET_URL_FIELD_NUMBER: builtins.int
    TARGET_URL_FIELD_NUMBER: builtins.int
    PLACEMENT_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    placement: typing.Text = ...
    display_name: typing.Text = ...
    group_placement_target_url: typing.Text = ...
    target_url: typing.Text = ...
    placement_type: google.ads.google_ads.v6.proto.enums.placement_type_pb2.PlacementTypeEnum.PlacementType.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        placement: typing.Text = ...,
        display_name: typing.Text = ...,
        group_placement_target_url: typing.Text = ...,
        target_url: typing.Text = ...,
        placement_type: google.ads.google_ads.v6.proto.enums.placement_type_pb2.PlacementTypeEnum.PlacementType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_display_name",
            b"_display_name",
            "_group_placement_target_url",
            b"_group_placement_target_url",
            "_placement",
            b"_placement",
            "_target_url",
            b"_target_url",
            "display_name",
            b"display_name",
            "group_placement_target_url",
            b"group_placement_target_url",
            "placement",
            b"placement",
            "target_url",
            b"target_url",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_display_name",
            b"_display_name",
            "_group_placement_target_url",
            b"_group_placement_target_url",
            "_placement",
            b"_placement",
            "_target_url",
            b"_target_url",
            "display_name",
            b"display_name",
            "group_placement_target_url",
            b"group_placement_target_url",
            "placement",
            b"placement",
            "placement_type",
            b"placement_type",
            "resource_name",
            b"resource_name",
            "target_url",
            b"target_url",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_display_name", b"_display_name"]
    ) -> typing_extensions.Literal["display_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_group_placement_target_url", b"_group_placement_target_url"
        ],
    ) -> typing_extensions.Literal["group_placement_target_url"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_placement", b"_placement"]
    ) -> typing_extensions.Literal["placement"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_target_url", b"_target_url"]
    ) -> typing_extensions.Literal["target_url"]: ...

global___DetailPlacementView = DetailPlacementView



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.resources.feed_item_target_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetFeedItemTargetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetFeedItemTargetRequest = GetFeedItemTargetRequest

class MutateFeedItemTargetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___FeedItemTargetOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operations: typing.Optional[
            typing.Iterable[global___FeedItemTargetOperation]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id", b"customer_id", "operations", b"operations"
        ],
    ) -> None: ...

global___MutateFeedItemTargetsRequest = MutateFeedItemTargetsRequest

class FeedItemTargetOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CREATE_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    remove: typing.Text = ...
    @property
    def create(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.feed_item_target_pb2.FeedItemTarget: ...
    def __init__(
        self,
        *,
        create: typing.Optional[
            google.ads.google_ads.v4.proto.resources.feed_item_target_pb2.FeedItemTarget
        ] = ...,
        remove: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["create", "remove"]: ...

global___FeedItemTargetOperation = FeedItemTargetOperation

class MutateFeedItemTargetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MutateFeedItemTargetResult
    ]: ...
    def __init__(
        self,
        *,
        results: typing.Optional[
            typing.Iterable[global___MutateFeedItemTargetResult]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["results", b"results"]
    ) -> None: ...

global___MutateFeedItemTargetsResponse = MutateFeedItemTargetsResponse

class MutateFeedItemTargetResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___MutateFeedItemTargetResult = MutateFeedItemTargetResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.placement_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DetailPlacementView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    GROUP_PLACEMENT_TARGET_URL_FIELD_NUMBER: builtins.int
    TARGET_URL_FIELD_NUMBER: builtins.int
    PLACEMENT_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    placement_type: google.ads.google_ads.v5.proto.enums.placement_type_pb2.PlacementTypeEnum.PlacementType.V = (
        ...
    )
    @property
    def placement(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def display_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def group_placement_target_url(
        self,
    ) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def target_url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        placement: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        display_name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        group_placement_target_url: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        target_url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        placement_type: google.ads.google_ads.v5.proto.enums.placement_type_pb2.PlacementTypeEnum.PlacementType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "display_name",
            b"display_name",
            "group_placement_target_url",
            b"group_placement_target_url",
            "placement",
            b"placement",
            "target_url",
            b"target_url",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "display_name",
            b"display_name",
            "group_placement_target_url",
            b"group_placement_target_url",
            "placement",
            b"placement",
            "placement_type",
            b"placement_type",
            "resource_name",
            b"resource_name",
            "target_url",
            b"target_url",
        ],
    ) -> None: ...

global___DetailPlacementView = DetailPlacementView



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.interaction_event_type_pb2
import google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Metrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ABSOLUTE_TOP_IMPRESSION_PERCENTAGE_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_CPM_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_CTR_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_IMPRESSIONS_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_MEASURABILITY_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_MEASURABLE_COST_MICROS_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_MEASURABLE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    ACTIVE_VIEW_VIEWABILITY_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_INTERACTIONS_RATE_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_VALUE_PER_COST_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_CLICK_TO_CALL_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_DIRECTIONS_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_INTERACTIONS_VALUE_PER_INTERACTION_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_MENU_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_ORDER_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_OTHER_ENGAGEMENT_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_STORE_VISIT_FIELD_NUMBER: builtins.int
    ALL_CONVERSIONS_FROM_STORE_WEBSITE_FIELD_NUMBER: builtins.int
    AVERAGE_COST_FIELD_NUMBER: builtins.int
    AVERAGE_CPC_FIELD_NUMBER: builtins.int
    AVERAGE_CPE_FIELD_NUMBER: builtins.int
    AVERAGE_CPM_FIELD_NUMBER: builtins.int
    AVERAGE_CPV_FIELD_NUMBER: builtins.int
    AVERAGE_PAGE_VIEWS_FIELD_NUMBER: builtins.int
    AVERAGE_TIME_ON_SITE_FIELD_NUMBER: builtins.int
    BENCHMARK_AVERAGE_MAX_CPC_FIELD_NUMBER: builtins.int
    BENCHMARK_CTR_FIELD_NUMBER: builtins.int
    BOUNCE_RATE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COMBINED_CLICKS_FIELD_NUMBER: builtins.int
    COMBINED_CLICKS_PER_QUERY_FIELD_NUMBER: builtins.int
    COMBINED_QUERIES_FIELD_NUMBER: builtins.int
    CONTENT_BUDGET_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    CONTENT_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    CONVERSION_LAST_RECEIVED_REQUEST_DATE_TIME_FIELD_NUMBER: builtins.int
    CONVERSION_LAST_CONVERSION_DATE_FIELD_NUMBER: builtins.int
    CONTENT_RANK_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    CONVERSIONS_FROM_INTERACTIONS_RATE_FIELD_NUMBER: builtins.int
    CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CONVERSIONS_VALUE_PER_COST_FIELD_NUMBER: builtins.int
    CONVERSIONS_FROM_INTERACTIONS_VALUE_PER_INTERACTION_FIELD_NUMBER: builtins.int
    CONVERSIONS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    COST_PER_ALL_CONVERSIONS_FIELD_NUMBER: builtins.int
    COST_PER_CONVERSION_FIELD_NUMBER: builtins.int
    COST_PER_CURRENT_MODEL_ATTRIBUTED_CONVERSION_FIELD_NUMBER: builtins.int
    CROSS_DEVICE_CONVERSIONS_FIELD_NUMBER: builtins.int
    CTR_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_FROM_INTERACTIONS_RATE_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_FROM_INTERACTIONS_VALUE_PER_INTERACTION_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CURRENT_MODEL_ATTRIBUTED_CONVERSIONS_VALUE_PER_COST_FIELD_NUMBER: builtins.int
    ENGAGEMENT_RATE_FIELD_NUMBER: builtins.int
    ENGAGEMENTS_FIELD_NUMBER: builtins.int
    HOTEL_AVERAGE_LEAD_VALUE_MICROS_FIELD_NUMBER: builtins.int
    HOTEL_PRICE_DIFFERENCE_PERCENTAGE_FIELD_NUMBER: builtins.int
    HOTEL_ELIGIBLE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    HISTORICAL_CREATIVE_QUALITY_SCORE_FIELD_NUMBER: builtins.int
    HISTORICAL_LANDING_PAGE_QUALITY_SCORE_FIELD_NUMBER: builtins.int
    HISTORICAL_QUALITY_SCORE_FIELD_NUMBER: builtins.int
    HISTORICAL_SEARCH_PREDICTED_CTR_FIELD_NUMBER: builtins.int
    GMAIL_FORWARDS_FIELD_NUMBER: builtins.int
    GMAIL_SAVES_FIELD_NUMBER: builtins.int
    GMAIL_SECONDARY_CLICKS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FROM_STORE_REACH_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    INTERACTION_RATE_FIELD_NUMBER: builtins.int
    INTERACTIONS_FIELD_NUMBER: builtins.int
    INTERACTION_EVENT_TYPES_FIELD_NUMBER: builtins.int
    INVALID_CLICK_RATE_FIELD_NUMBER: builtins.int
    INVALID_CLICKS_FIELD_NUMBER: builtins.int
    MESSAGE_CHATS_FIELD_NUMBER: builtins.int
    MESSAGE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    MESSAGE_CHAT_RATE_FIELD_NUMBER: builtins.int
    MOBILE_FRIENDLY_CLICKS_PERCENTAGE_FIELD_NUMBER: builtins.int
    ORGANIC_CLICKS_FIELD_NUMBER: builtins.int
    ORGANIC_CLICKS_PER_QUERY_FIELD_NUMBER: builtins.int
    ORGANIC_IMPRESSIONS_FIELD_NUMBER: builtins.int
    ORGANIC_IMPRESSIONS_PER_QUERY_FIELD_NUMBER: builtins.int
    ORGANIC_QUERIES_FIELD_NUMBER: builtins.int
    PERCENT_NEW_VISITORS_FIELD_NUMBER: builtins.int
    PHONE_CALLS_FIELD_NUMBER: builtins.int
    PHONE_IMPRESSIONS_FIELD_NUMBER: builtins.int
    PHONE_THROUGH_RATE_FIELD_NUMBER: builtins.int
    RELATIVE_CTR_FIELD_NUMBER: builtins.int
    SEARCH_ABSOLUTE_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_BUDGET_LOST_ABSOLUTE_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_BUDGET_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_BUDGET_LOST_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_CLICK_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_EXACT_MATCH_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_RANK_LOST_ABSOLUTE_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_RANK_LOST_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_RANK_LOST_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SEARCH_TOP_IMPRESSION_SHARE_FIELD_NUMBER: builtins.int
    SPEED_SCORE_FIELD_NUMBER: builtins.int
    TOP_IMPRESSION_PERCENTAGE_FIELD_NUMBER: builtins.int
    VALID_ACCELERATED_MOBILE_PAGES_CLICKS_PERCENTAGE_FIELD_NUMBER: builtins.int
    VALUE_PER_ALL_CONVERSIONS_FIELD_NUMBER: builtins.int
    VALUE_PER_CONVERSION_FIELD_NUMBER: builtins.int
    VALUE_PER_CURRENT_MODEL_ATTRIBUTED_CONVERSION_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_100_RATE_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_25_RATE_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_50_RATE_FIELD_NUMBER: builtins.int
    VIDEO_QUARTILE_75_RATE_FIELD_NUMBER: builtins.int
    VIDEO_VIEW_RATE_FIELD_NUMBER: builtins.int
    VIDEO_VIEWS_FIELD_NUMBER: builtins.int
    VIEW_THROUGH_CONVERSIONS_FIELD_NUMBER: builtins.int
    historical_creative_quality_score: google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
        ...
    )
    historical_landing_page_quality_score: google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
        ...
    )
    historical_search_predicted_ctr: google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
        ...
    )
    interaction_event_types: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        google.ads.google_ads.v4.proto.enums.interaction_event_type_pb2.InteractionEventTypeEnum.InteractionEventType.V
    ] = ...
    @property
    def absolute_top_impression_percentage(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def active_view_cpm(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def active_view_ctr(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def active_view_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def active_view_measurability(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def active_view_measurable_cost_micros(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def active_view_measurable_impressions(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def active_view_viewability(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_interactions_rate(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_value(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_value_per_cost(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_click_to_call(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_directions(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_interactions_value_per_interaction(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_menu(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_order(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_other_engagement(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_store_visit(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def all_conversions_from_store_website(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_cost(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_cpc(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_cpe(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_cpm(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_cpv(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_page_views(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def average_time_on_site(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def benchmark_average_max_cpc(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def benchmark_ctr(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def bounce_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def combined_clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def combined_clicks_per_query(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def combined_queries(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def content_budget_lost_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def content_impression_share(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def conversion_last_received_request_date_time(
        self,
    ) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def conversion_last_conversion_date(
        self,
    ) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def content_rank_lost_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def conversions_from_interactions_rate(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def conversions_value(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def conversions_value_per_cost(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def conversions_from_interactions_value_per_interaction(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cost_per_all_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def cost_per_conversion(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def cost_per_current_model_attributed_conversion(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def cross_device_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def ctr(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def current_model_attributed_conversions(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def current_model_attributed_conversions_from_interactions_rate(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def current_model_attributed_conversions_from_interactions_value_per_interaction(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def current_model_attributed_conversions_value(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def current_model_attributed_conversions_value_per_cost(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def engagement_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def engagements(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def hotel_average_lead_value_micros(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def hotel_price_difference_percentage(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def hotel_eligible_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def historical_quality_score(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def gmail_forwards(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def gmail_saves(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def gmail_secondary_clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions_from_store_reach(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def interaction_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def interactions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def invalid_click_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def invalid_clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def message_chats(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def message_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def message_chat_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def mobile_friendly_clicks_percentage(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def organic_clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def organic_clicks_per_query(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def organic_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def organic_impressions_per_query(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def organic_queries(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def percent_new_visitors(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def phone_calls(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def phone_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def phone_through_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def relative_ctr(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_absolute_top_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_budget_lost_absolute_top_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_budget_lost_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_budget_lost_top_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_click_share(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_exact_match_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_impression_share(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_rank_lost_absolute_top_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_rank_lost_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_rank_lost_top_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def search_top_impression_share(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def speed_score(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def top_impression_percentage(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def valid_accelerated_mobile_pages_clicks_percentage(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def value_per_all_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def value_per_conversion(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def value_per_current_model_attributed_conversion(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def video_quartile_100_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def video_quartile_25_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def video_quartile_50_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def video_quartile_75_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def video_view_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def video_views(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def view_through_conversions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        absolute_top_impression_percentage: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        active_view_cpm: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        active_view_ctr: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        active_view_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        active_view_measurability: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        active_view_measurable_cost_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        active_view_measurable_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        active_view_viewability: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_interactions_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_value_per_cost: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_click_to_call: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_directions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_interactions_value_per_interaction: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_menu: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_order: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_other_engagement: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_store_visit: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        all_conversions_from_store_website: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        average_cost: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        average_cpc: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        average_cpe: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        average_cpm: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        average_cpv: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        average_page_views: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        average_time_on_site: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        benchmark_average_max_cpc: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        benchmark_ctr: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        bounce_rate: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        combined_clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        combined_clicks_per_query: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        combined_queries: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        content_budget_lost_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        content_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        conversion_last_received_request_date_time: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        conversion_last_conversion_date: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        content_rank_lost_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        conversions_from_interactions_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        conversions_value_per_cost: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        conversions_from_interactions_value_per_interaction: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        conversions: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        cost_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        cost_per_all_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        cost_per_conversion: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        cost_per_current_model_attributed_conversion: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        cross_device_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        ctr: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        current_model_attributed_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        current_model_attributed_conversions_from_interactions_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        current_model_attributed_conversions_from_interactions_value_per_interaction: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        current_model_attributed_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        current_model_attributed_conversions_value_per_cost: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        engagement_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        engagements: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        hotel_average_lead_value_micros: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        hotel_price_difference_percentage: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        hotel_eligible_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        historical_creative_quality_score: google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
        historical_landing_page_quality_score: google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
        historical_quality_score: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        historical_search_predicted_ctr: google.ads.google_ads.v4.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
        gmail_forwards: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        gmail_saves: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        gmail_secondary_clicks: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        impressions_from_store_reach: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        impressions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        interaction_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        interactions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        interaction_event_types: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.enums.interaction_event_type_pb2.InteractionEventTypeEnum.InteractionEventType.V
            ]
        ] = ...,
        invalid_click_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        invalid_clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        message_chats: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        message_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        message_chat_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        mobile_friendly_clicks_percentage: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        organic_clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        organic_clicks_per_query: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        organic_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        organic_impressions_per_query: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        organic_queries: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        percent_new_visitors: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        phone_calls: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        phone_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        phone_through_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        relative_ctr: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        search_absolute_top_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_budget_lost_absolute_top_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_budget_lost_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_budget_lost_top_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_click_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_exact_match_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_rank_lost_absolute_top_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_rank_lost_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_rank_lost_top_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        search_top_impression_share: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        speed_score: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        top_impression_percentage: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        valid_accelerated_mobile_pages_clicks_percentage: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        value_per_all_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        value_per_conversion: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        value_per_current_model_attributed_conversion: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        video_quartile_100_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        video_quartile_25_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        video_quartile_50_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        video_quartile_75_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        video_view_rate: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        video_views: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        view_through_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "absolute_top_impression_percentage",
            b"absolute_top_impression_percentage",
            "active_view_cpm",
            b"active_view_cpm",
            "active_view_ctr",
            b"active_view_ctr",
            "active_view_impressions",
            b"active_view_impressions",
            "active_view_measurability",
            b"active_view_measurability",
            "active_view_measurable_cost_micros",
            b"active_view_measurable_cost_micros",
            "active_view_measurable_impressions",
            b"active_view_measurable_impressions",
            "active_view_viewability",
            b"active_view_viewability",
            "all_conversions",
            b"all_conversions",
            "all_conversions_from_click_to_call",
            b"all_conversions_from_click_to_call",
            "all_conversions_from_directions",
            b"all_conversions_from_directions",
            "all_conversions_from_interactions_rate",
            b"all_conversions_from_interactions_rate",
            "all_conversions_from_interactions_value_per_interaction",
            b"all_conversions_from_interactions_value_per_interaction",
            "all_conversions_from_menu",
            b"all_conversions_from_menu",
            "all_conversions_from_order",
            b"all_conversions_from_order",
            "all_conversions_from_other_engagement",
            b"all_conversions_from_other_engagement",
            "all_conversions_from_store_visit",
            b"all_conversions_from_store_visit",
            "all_conversions_from_store_website",
            b"all_conversions_from_store_website",
            "all_conversions_value",
            b"all_conversions_value",
            "all_conversions_value_per_cost",
            b"all_conversions_value_per_cost",
            "average_cost",
            b"average_cost",
            "average_cpc",
            b"average_cpc",
            "average_cpe",
            b"average_cpe",
            "average_cpm",
            b"average_cpm",
            "average_cpv",
            b"average_cpv",
            "average_page_views",
            b"average_page_views",
            "average_time_on_site",
            b"average_time_on_site",
            "benchmark_average_max_cpc",
            b"benchmark_average_max_cpc",
            "benchmark_ctr",
            b"benchmark_ctr",
            "bounce_rate",
            b"bounce_rate",
            "clicks",
            b"clicks",
            "combined_clicks",
            b"combined_clicks",
            "combined_clicks_per_query",
            b"combined_clicks_per_query",
            "combined_queries",
            b"combined_queries",
            "content_budget_lost_impression_share",
            b"content_budget_lost_impression_share",
            "content_impression_share",
            b"content_impression_share",
            "content_rank_lost_impression_share",
            b"content_rank_lost_impression_share",
            "conversion_last_conversion_date",
            b"conversion_last_conversion_date",
            "conversion_last_received_request_date_time",
            b"conversion_last_received_request_date_time",
            "conversions",
            b"conversions",
            "conversions_from_interactions_rate",
            b"conversions_from_interactions_rate",
            "conversions_from_interactions_value_per_interaction",
            b"conversions_from_interactions_value_per_interaction",
            "conversions_value",
            b"conversions_value",
            "conversions_value_per_cost",
            b"conversions_value_per_cost",
            "cost_micros",
            b"cost_micros",
            "cost_per_all_conversions",
            b"cost_per_all_conversions",
            "cost_per_conversion",
            b"cost_per_conversion",
            "cost_per_current_model_attributed_conversion",
            b"cost_per_current_model_attributed_conversion",
            "cross_device_conversions",
            b"cross_device_conversions",
            "ctr",
            b"ctr",
            "current_model_attributed_conversions",
            b"current_model_attributed_conversions",
            "current_model_attributed_conversions_from_interactions_rate",
            b"current_model_attributed_conversions_from_interactions_rate",
            "current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"current_model_attributed_conversions_from_interactions_value_per_interaction",
            "current_model_attributed_conversions_value",
            b"current_model_attributed_conversions_value",
            "current_model_attributed_conversions_value_per_cost",
            b"current_model_attributed_conversions_value_per_cost",
            "engagement_rate",
            b"engagement_rate",
            "engagements",
            b"engagements",
            "gmail_forwards",
            b"gmail_forwards",
            "gmail_saves",
            b"gmail_saves",
            "gmail_secondary_clicks",
            b"gmail_secondary_clicks",
            "historical_quality_score",
            b"historical_quality_score",
            "hotel_average_lead_value_micros",
            b"hotel_average_lead_value_micros",
            "hotel_eligible_impressions",
            b"hotel_eligible_impressions",
            "hotel_price_difference_percentage",
            b"hotel_price_difference_percentage",
            "impressions",
            b"impressions",
            "impressions_from_store_reach",
            b"impressions_from_store_reach",
            "interaction_rate",
            b"interaction_rate",
            "interactions",
            b"interactions",
            "invalid_click_rate",
            b"invalid_click_rate",
            "invalid_clicks",
            b"invalid_clicks",
            "message_chat_rate",
            b"message_chat_rate",
            "message_chats",
            b"message_chats",
            "message_impressions",
            b"message_impressions",
            "mobile_friendly_clicks_percentage",
            b"mobile_friendly_clicks_percentage",
            "organic_clicks",
            b"organic_clicks",
            "organic_clicks_per_query",
            b"organic_clicks_per_query",
            "organic_impressions",
            b"organic_impressions",
            "organic_impressions_per_query",
            b"organic_impressions_per_query",
            "organic_queries",
            b"organic_queries",
            "percent_new_visitors",
            b"percent_new_visitors",
            "phone_calls",
            b"phone_calls",
            "phone_impressions",
            b"phone_impressions",
            "phone_through_rate",
            b"phone_through_rate",
            "relative_ctr",
            b"relative_ctr",
            "search_absolute_top_impression_share",
            b"search_absolute_top_impression_share",
            "search_budget_lost_absolute_top_impression_share",
            b"search_budget_lost_absolute_top_impression_share",
            "search_budget_lost_impression_share",
            b"search_budget_lost_impression_share",
            "search_budget_lost_top_impression_share",
            b"search_budget_lost_top_impression_share",
            "search_click_share",
            b"search_click_share",
            "search_exact_match_impression_share",
            b"search_exact_match_impression_share",
            "search_impression_share",
            b"search_impression_share",
            "search_rank_lost_absolute_top_impression_share",
            b"search_rank_lost_absolute_top_impression_share",
            "search_rank_lost_impression_share",
            b"search_rank_lost_impression_share",
            "search_rank_lost_top_impression_share",
            b"search_rank_lost_top_impression_share",
            "search_top_impression_share",
            b"search_top_impression_share",
            "speed_score",
            b"speed_score",
            "top_impression_percentage",
            b"top_impression_percentage",
            "valid_accelerated_mobile_pages_clicks_percentage",
            b"valid_accelerated_mobile_pages_clicks_percentage",
            "value_per_all_conversions",
            b"value_per_all_conversions",
            "value_per_conversion",
            b"value_per_conversion",
            "value_per_current_model_attributed_conversion",
            b"value_per_current_model_attributed_conversion",
            "video_quartile_100_rate",
            b"video_quartile_100_rate",
            "video_quartile_25_rate",
            b"video_quartile_25_rate",
            "video_quartile_50_rate",
            b"video_quartile_50_rate",
            "video_quartile_75_rate",
            b"video_quartile_75_rate",
            "video_view_rate",
            b"video_view_rate",
            "video_views",
            b"video_views",
            "view_through_conversions",
            b"view_through_conversions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "absolute_top_impression_percentage",
            b"absolute_top_impression_percentage",
            "active_view_cpm",
            b"active_view_cpm",
            "active_view_ctr",
            b"active_view_ctr",
            "active_view_impressions",
            b"active_view_impressions",
            "active_view_measurability",
            b"active_view_measurability",
            "active_view_measurable_cost_micros",
            b"active_view_measurable_cost_micros",
            "active_view_measurable_impressions",
            b"active_view_measurable_impressions",
            "active_view_viewability",
            b"active_view_viewability",
            "all_conversions",
            b"all_conversions",
            "all_conversions_from_click_to_call",
            b"all_conversions_from_click_to_call",
            "all_conversions_from_directions",
            b"all_conversions_from_directions",
            "all_conversions_from_interactions_rate",
            b"all_conversions_from_interactions_rate",
            "all_conversions_from_interactions_value_per_interaction",
            b"all_conversions_from_interactions_value_per_interaction",
            "all_conversions_from_menu",
            b"all_conversions_from_menu",
            "all_conversions_from_order",
            b"all_conversions_from_order",
            "all_conversions_from_other_engagement",
            b"all_conversions_from_other_engagement",
            "all_conversions_from_store_visit",
            b"all_conversions_from_store_visit",
            "all_conversions_from_store_website",
            b"all_conversions_from_store_website",
            "all_conversions_value",
            b"all_conversions_value",
            "all_conversions_value_per_cost",
            b"all_conversions_value_per_cost",
            "average_cost",
            b"average_cost",
            "average_cpc",
            b"average_cpc",
            "average_cpe",
            b"average_cpe",
            "average_cpm",
            b"average_cpm",
            "average_cpv",
            b"average_cpv",
            "average_page_views",
            b"average_page_views",
            "average_time_on_site",
            b"average_time_on_site",
            "benchmark_average_max_cpc",
            b"benchmark_average_max_cpc",
            "benchmark_ctr",
            b"benchmark_ctr",
            "bounce_rate",
            b"bounce_rate",
            "clicks",
            b"clicks",
            "combined_clicks",
            b"combined_clicks",
            "combined_clicks_per_query",
            b"combined_clicks_per_query",
            "combined_queries",
            b"combined_queries",
            "content_budget_lost_impression_share",
            b"content_budget_lost_impression_share",
            "content_impression_share",
            b"content_impression_share",
            "content_rank_lost_impression_share",
            b"content_rank_lost_impression_share",
            "conversion_last_conversion_date",
            b"conversion_last_conversion_date",
            "conversion_last_received_request_date_time",
            b"conversion_last_received_request_date_time",
            "conversions",
            b"conversions",
            "conversions_from_interactions_rate",
            b"conversions_from_interactions_rate",
            "conversions_from_interactions_value_per_interaction",
            b"conversions_from_interactions_value_per_interaction",
            "conversions_value",
            b"conversions_value",
            "conversions_value_per_cost",
            b"conversions_value_per_cost",
            "cost_micros",
            b"cost_micros",
            "cost_per_all_conversions",
            b"cost_per_all_conversions",
            "cost_per_conversion",
            b"cost_per_conversion",
            "cost_per_current_model_attributed_conversion",
            b"cost_per_current_model_attributed_conversion",
            "cross_device_conversions",
            b"cross_device_conversions",
            "ctr",
            b"ctr",
            "current_model_attributed_conversions",
            b"current_model_attributed_conversions",
            "current_model_attributed_conversions_from_interactions_rate",
            b"current_model_attributed_conversions_from_interactions_rate",
            "current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"current_model_attributed_conversions_from_interactions_value_per_interaction",
            "current_model_attributed_conversions_value",
            b"current_model_attributed_conversions_value",
            "current_model_attributed_conversions_value_per_cost",
            b"current_model_attributed_conversions_value_per_cost",
            "engagement_rate",
            b"engagement_rate",
            "engagements",
            b"engagements",
            "gmail_forwards",
            b"gmail_forwards",
            "gmail_saves",
            b"gmail_saves",
            "gmail_secondary_clicks",
            b"gmail_secondary_clicks",
            "historical_creative_quality_score",
            b"historical_creative_quality_score",
            "historical_landing_page_quality_score",
            b"historical_landing_page_quality_score",
            "historical_quality_score",
            b"historical_quality_score",
            "historical_search_predicted_ctr",
            b"historical_search_predicted_ctr",
            "hotel_average_lead_value_micros",
            b"hotel_average_lead_value_micros",
            "hotel_eligible_impressions",
            b"hotel_eligible_impressions",
            "hotel_price_difference_percentage",
            b"hotel_price_difference_percentage",
            "impressions",
            b"impressions",
            "impressions_from_store_reach",
            b"impressions_from_store_reach",
            "interaction_event_types",
            b"interaction_event_types",
            "interaction_rate",
            b"interaction_rate",
            "interactions",
            b"interactions",
            "invalid_click_rate",
            b"invalid_click_rate",
            "invalid_clicks",
            b"invalid_clicks",
            "message_chat_rate",
            b"message_chat_rate",
            "message_chats",
            b"message_chats",
            "message_impressions",
            b"message_impressions",
            "mobile_friendly_clicks_percentage",
            b"mobile_friendly_clicks_percentage",
            "organic_clicks",
            b"organic_clicks",
            "organic_clicks_per_query",
            b"organic_clicks_per_query",
            "organic_impressions",
            b"organic_impressions",
            "organic_impressions_per_query",
            b"organic_impressions_per_query",
            "organic_queries",
            b"organic_queries",
            "percent_new_visitors",
            b"percent_new_visitors",
            "phone_calls",
            b"phone_calls",
            "phone_impressions",
            b"phone_impressions",
            "phone_through_rate",
            b"phone_through_rate",
            "relative_ctr",
            b"relative_ctr",
            "search_absolute_top_impression_share",
            b"search_absolute_top_impression_share",
            "search_budget_lost_absolute_top_impression_share",
            b"search_budget_lost_absolute_top_impression_share",
            "search_budget_lost_impression_share",
            b"search_budget_lost_impression_share",
            "search_budget_lost_top_impression_share",
            b"search_budget_lost_top_impression_share",
            "search_click_share",
            b"search_click_share",
            "search_exact_match_impression_share",
            b"search_exact_match_impression_share",
            "search_impression_share",
            b"search_impression_share",
            "search_rank_lost_absolute_top_impression_share",
            b"search_rank_lost_absolute_top_impression_share",
            "search_rank_lost_impression_share",
            b"search_rank_lost_impression_share",
            "search_rank_lost_top_impression_share",
            b"search_rank_lost_top_impression_share",
            "search_top_impression_share",
            b"search_top_impression_share",
            "speed_score",
            b"speed_score",
            "top_impression_percentage",
            b"top_impression_percentage",
            "valid_accelerated_mobile_pages_clicks_percentage",
            b"valid_accelerated_mobile_pages_clicks_percentage",
            "value_per_all_conversions",
            b"value_per_all_conversions",
            "value_per_conversion",
            b"value_per_conversion",
            "value_per_current_model_attributed_conversion",
            b"value_per_current_model_attributed_conversion",
            "video_quartile_100_rate",
            b"video_quartile_100_rate",
            "video_quartile_25_rate",
            b"video_quartile_25_rate",
            "video_quartile_50_rate",
            b"video_quartile_50_rate",
            "video_quartile_75_rate",
            b"video_quartile_75_rate",
            "video_view_rate",
            b"video_view_rate",
            "video_views",
            b"video_views",
            "view_through_conversions",
            b"view_through_conversions",
        ],
    ) -> None: ...

global___Metrics = Metrics



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdvertisingChannelTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdvertisingChannelType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdvertisingChannelType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(0)
        UNKNOWN = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(1)
        SEARCH = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(2)
        DISPLAY = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(3)
        SHOPPING = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(4)
        HOTEL = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(5)
        VIDEO = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(6)
        MULTI_CHANNEL = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(7)
        LOCAL = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(8)
        SMART = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(9)
    class AdvertisingChannelType(metaclass=_AdvertisingChannelType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(0)
    UNKNOWN = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(1)
    SEARCH = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(2)
    DISPLAY = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(3)
    SHOPPING = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(4)
    HOTEL = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(5)
    VIDEO = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(6)
    MULTI_CHANNEL = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(7)
    LOCAL = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(8)
    SMART = AdvertisingChannelTypeEnum.AdvertisingChannelType.V(9)
    def __init__(
        self,
    ) -> None: ...

global___AdvertisingChannelTypeEnum = AdvertisingChannelTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UrlCollection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    URL_COLLECTION_ID_FIELD_NUMBER: builtins.int
    FINAL_URLS_FIELD_NUMBER: builtins.int
    FINAL_MOBILE_URLS_FIELD_NUMBER: builtins.int
    TRACKING_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    @property
    def url_collection_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def final_urls(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def final_mobile_urls(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def tracking_url_template(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        url_collection_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        final_urls: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        final_mobile_urls: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        tracking_url_template: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "tracking_url_template",
            b"tracking_url_template",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_urls",
            b"final_urls",
            "tracking_url_template",
            b"tracking_url_template",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> None: ...

global___UrlCollection = UrlCollection
